@@ -1,46 +1,104 @@
 /*
 	File:		MBCBoardView.mm
 	Contains:	General view handling infrastructure
-	Copyright:	 2002-2005 Apple Computer, Inc. All rights reserved.
+	Version:	1.0
+	Copyright:	 2002 by Apple Computer, Inc., all rights reserved.
 
-	IMPORTANT: This Apple software is supplied to you by Apple Computer,
-	Inc.  ("Apple") in consideration of your agreement to the following
-	terms, and your use, installation, modification or redistribution of
-	this Apple software constitutes acceptance of these terms.  If you do
-	not agree with these terms, please do not use, install, modify or
-	redistribute this Apple software.
-	
-	In consideration of your agreement to abide by the following terms,
-	and subject to these terms, Apple grants you a personal, non-exclusive
-	license, under Apple's copyrights in this original Apple software (the
-	"Apple Software"), to use, reproduce, modify and redistribute the
-	Apple Software, with or without modifications, in source and/or binary
-	forms; provided that if you redistribute the Apple Software in its
-	entirety and without modifications, you must retain this notice and
-	the following text and disclaimers in all such redistributions of the
-	Apple Software.  Neither the name, trademarks, service marks or logos
-	of Apple Computer, Inc. may be used to endorse or promote products
-	derived from the Apple Software without specific prior written
-	permission from Apple.  Except as expressly stated in this notice, no
-	other rights or licenses, express or implied, are granted by Apple
-	herein, including but not limited to any patent rights that may be
-	infringed by your derivative works or by other works in which the
-	Apple Software may be incorporated.
-	
-	The Apple Software is provided by Apple on an "AS IS" basis.  APPLE
-	MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION
-	THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND
-	FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE APPLE SOFTWARE OR ITS
-	USE AND OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
-	
-	IN NO EVENT SHALL APPLE BE LIABLE FOR ANY SPECIAL, INDIRECT,
-	INCIDENTAL OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-	PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
-	REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE APPLE SOFTWARE,
-	HOWEVER CAUSED AND WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING
-	NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN IF APPLE HAS BEEN
-	ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+	File Ownership:
+
+		DRI:				Matthias Neeracher    x43683
+
+	Writers:
+
+		(MN)	Matthias Neeracher
+
+	Change History (most recent first):
+
+		$Log: MBCBoardView.mm,v $
+		Revision 1.28  2004/08/16 07:50:55  neerache
+		Support accessibility
+		
+		Revision 1.27  2003/07/14 23:21:49  neerache
+		Move promotion defaults into MBCBoard
+		
+		Revision 1.26  2003/07/07 09:16:42  neerache
+		Textured windows are too slow for low end machines, disable
+		
+		Revision 1.25  2003/07/07 08:47:53  neerache
+		Switch to textured main window
+		
+		Revision 1.24  2003/06/30 05:16:30  neerache
+		Transfer move execution to Controller
+		
+		Revision 1.23  2003/06/16 02:18:03  neerache
+		Implement floating board
+		
+		Revision 1.22  2003/06/15 21:13:09  neerache
+		Adjust lights, fix animation, work on other drawing issues
+		
+		Revision 1.21  2003/06/05 08:31:26  neerache
+		Added Tuner
+		
+		Revision 1.20  2003/06/04 23:14:05  neerache
+		Neater manipulation widget; remove obsolete graphics options
+		
+		Revision 1.19  2003/06/04 09:25:47  neerache
+		New and improved board manipulation metaphor
+		
+		Revision 1.18  2003/06/02 05:44:48  neerache
+		Implement direct board manipulation
+		
+		Revision 1.17  2003/06/02 04:21:40  neerache
+		Start implementing drawing styles for board elements
+		
+		Revision 1.16  2003/05/24 20:28:27  neerache
+		Address race conditions between ploayer and engine
+		
+		Revision 1.15  2003/05/23 03:22:16  neerache
+		Add FPS computation
+		
+		Revision 1.14  2003/05/05 23:50:40  neerache
+		Tweak appearance, add border, add animations
+		
+		Revision 1.13  2003/05/02 01:16:33  neerache
+		Simplify drawing methods
+		
+		Revision 1.12  2003/04/28 22:13:25  neerache
+		Eliminate drawBoardPlane
+		
+		Revision 1.11  2003/04/25 22:26:23  neerache
+		Simplify mouse model, fix startup bug
+		
+		Revision 1.10  2003/04/24 23:20:35  neeri
+		Support pawn promotions
+		
+		Revision 1.9  2003/04/02 18:45:57  neeri
+		Experiment with different snap techniques
+		
+		Revision 1.8  2003/03/28 01:31:07  neeri
+		Support hints, last move
+		
+		Revision 1.7  2002/12/04 02:30:50  neeri
+		Experiment (unsuccessfully so far) with ways to speed up piece movement
+		
+		Revision 1.6  2002/10/15 22:49:39  neeri
+		Add support for texture styles
+		
+		Revision 1.5  2002/10/08 23:02:54  neeri
+		Rotated board, changeable colors
+		
+		Revision 1.4  2002/09/13 23:57:05  neeri
+		Support for Crazyhouse display and mouse
+		
+		Revision 1.3  2002/09/12 17:46:46  neeri
+		Introduce dual board representation, in-hand pieces
+		
+		Revision 1.2  2002/08/26 23:11:17  neeri
+		Switched to Azimuth/Elevation based Camera positioning model
+		
+		Revision 1.1  2002/08/22 23:47:06  neeri
+		Initial Checkin
+		
 */
 #import "MBCBoardView.h"
 #import "MBCBoardAnimation.h"
@@ -140,7 +198,7 @@ void MBCColor::SetColor(NSColor * newColor)
 	fWantMouse			= false;
 	fNeedPerspective	= true;
 	fAmbient			= light_ambient;
-	memcpy(fLightPos, light_pos, sizeof(fLightPos));
+	fLightPos			= light_pos;
 
 	fHandCursor			= [[NSCursor alloc]
 							  initWithImage:[NSImage imageNamed:@"handCursor"]
