@@ -1,49 +1,56 @@
 /*
 	File:		MBCBoardViewModels.mm
 	Contains:	Define OpenGL models for chess pieces
-	Copyright:	 2002-2003 Apple Computer, Inc. All rights reserved.
+	Version:	1.0
+	Copyright:	 2002 by Apple Computer, Inc., all rights reserved.
 	
 	Derived from glChess, Copyright  2002 Robert Ancell and Michael Duelli
 	Permission granted to Apple to relicense under the following terms:
 
-	IMPORTANT: This Apple software is supplied to you by Apple Computer,
-	Inc.  ("Apple") in consideration of your agreement to the following
-	terms, and your use, installation, modification or redistribution of
-	this Apple software constitutes acceptance of these terms.  If you do
-	not agree with these terms, please do not use, install, modify or
-	redistribute this Apple software.
-	
-	In consideration of your agreement to abide by the following terms,
-	and subject to these terms, Apple grants you a personal, non-exclusive
-	license, under Apple's copyrights in this original Apple software (the
-	"Apple Software"), to use, reproduce, modify and redistribute the
-	Apple Software, with or without modifications, in source and/or binary
-	forms; provided that if you redistribute the Apple Software in its
-	entirety and without modifications, you must retain this notice and
-	the following text and disclaimers in all such redistributions of the
-	Apple Software.  Neither the name, trademarks, service marks or logos
-	of Apple Computer, Inc. may be used to endorse or promote products
-	derived from the Apple Software without specific prior written
-	permission from Apple.  Except as expressly stated in this notice, no
-	other rights or licenses, express or implied, are granted by Apple
-	herein, including but not limited to any patent rights that may be
-	infringed by your derivative works or by other works in which the
-	Apple Software may be incorporated.
-	
-	The Apple Software is provided by Apple on an "AS IS" basis.  APPLE
-	MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION
-	THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND
-	FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE APPLE SOFTWARE OR ITS
-	USE AND OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
-	
-	IN NO EVENT SHALL APPLE BE LIABLE FOR ANY SPECIAL, INDIRECT,
-	INCIDENTAL OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-	PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
-	REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE APPLE SOFTWARE,
-	HOWEVER CAUSED AND WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING
-	NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN IF APPLE HAS BEEN
-	ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+	File Ownership:
+
+		DRI:				Matthias Neeracher    x43683
+
+	Writers:
+
+		(MN)	Matthias Neeracher
+
+	Change History (most recent first):
+
+		$Log: MBCBoardViewModels.mm,v $
+		Revision 1.11  2004/07/10 04:53:29  neerache
+		Tweak visuals
+		
+		Revision 1.10  2003/11/06 23:30:51  neerache
+		Adjust wording as suggested by Joyce Chow
+		
+		Revision 1.9  2003/10/29 22:39:31  neerache
+		Add tools & clean up copyright references for release
+		
+		Revision 1.8  2003/07/17 23:30:07  neerache
+		Don't need CenterOfGravity info any longer
+		
+		Revision 1.7  2003/06/15 21:11:53  neerache
+		Fix holes in piece models, still some left in Knights
+		
+		Revision 1.6  2003/05/27 03:13:57  neerache
+		Rework game loading/saving code
+		
+		Revision 1.5  2003/05/23 03:21:52  neerache
+		Add polygon statistics
+		
+		Revision 1.4  2003/05/05 23:51:23  neerache
+		Use glu for rotated parts, fix knight texture mapping
+		
+		Revision 1.3  2003/05/02 01:16:55  neerache
+		Antialias squares, experiment with translucent board
+		
+		Revision 1.2  2002/10/15 22:49:40  neeri
+		Add support for texture styles
+		
+		Revision 1.1  2002/08/22 23:47:06  neeri
+		Initial Checkin
+		
 */
 
 #import "MBCBoardViewModels.h"
@@ -68,7 +75,7 @@ static int sPolyCount;
 #define POLY_STAT_QUAD()		POLY_STAT(2)
 #define POLY_STAT_TRIANGLE()	POLY_STAT(1)
 
-const float kPieceSize = 1.0f;
+const float kPieceSize = 0.85f;
 
 /* Revolutions start in the positive z-axis (towards camera) and go
  * anti-clockwise */
@@ -77,21 +84,25 @@ const float kPieceSize = 1.0f;
 int revolve_line(float *trace_r, float *trace_h, float max_iheight)
 {
 	const int	nsteps = 16;
-	const float kTexScale	= 10.0f;
+	const float kTexScale	= 10.0f*kPieceSize;
 	GLUquadricObj * q 		= gluNewQuadric();
 	gluQuadricNormals(q, GLU_SMOOTH);
 	gluQuadricTexture(q, true);
 	glPushMatrix();
 	glRotatef(-90.0f, 1.0f, 0.0f, 0.0f);
 	while (trace_r[1] != 0.0f || trace_h[1] != 0.0f) {
-		float	dh = trace_h[1]-trace_h[0];
-		if (dh == 0.0f) {
-			if (trace_r[1] > trace_r[0]) {
+		float   th0= trace_h[0]*kPieceSize;
+		float   th1= trace_h[1]*kPieceSize;
+		float   tr0= trace_r[0]*kPieceSize;
+		float   tr1= trace_r[1]*kPieceSize;
+		float	dh = th1-th0;
+		if (fabs(dh) < 0.00001f) {
+			if (tr1 > tr0) {
 				gluQuadricOrientation(q, GLU_INSIDE);
-				gluDisk(q, trace_r[0], trace_r[1], nsteps, 1);
+				gluDisk(q, tr0, tr1, nsteps, 1);
 				gluQuadricOrientation(q, GLU_OUTSIDE);
 			} else {
-				gluDisk(q, trace_r[1], trace_r[0], nsteps, 1);
+				gluDisk(q, tr1, tr0, nsteps, 1);
 			}
 			POLY_STAT(nsteps);
 		} else {
@@ -102,10 +113,10 @@ int revolve_line(float *trace_r, float *trace_h, float max_iheight)
 			if (dh < 0.0f) {
 				gluQuadricOrientation(q, GLU_INSIDE);
 				glTranslatef(0.0f, 0.0f, dh);
-				gluCylinder(q, trace_r[1], trace_r[0], -dh, nsteps, 1);
+				gluCylinder(q, tr1, tr0, -dh, nsteps, 1);
 				gluQuadricOrientation(q, GLU_OUTSIDE);
 			} else {
-				gluCylinder(q, trace_r[0], trace_r[1], dh, nsteps, 1);
+				gluCylinder(q, tr0, tr1, dh, nsteps, 1);
 				glTranslatef(0.0f, 0.0f, dh);
 			}
 			POLY_STAT(2*nsteps);
