@@ -1,49 +1,59 @@
 /*
 	File:		MBCBoardViewTextures.mm
 	Contains:	Load OpenGL textures from resources
-	Copyright:	 2002-2005 Apple Computer, Inc. All rights reserved.
+	Version:	1.0
+	Copyright:	 2002 by Apple Computer, Inc., all rights reserved.
 	
 	Derived from glChess, Copyright  2002 Robert Ancell and Michael Duelli
 	Permission granted to Apple to relicense under the following terms:
 
-	IMPORTANT: This Apple software is supplied to you by Apple Computer,
-	Inc.  ("Apple") in consideration of your agreement to the following
-	terms, and your use, installation, modification or redistribution of
-	this Apple software constitutes acceptance of these terms.  If you do
-	not agree with these terms, please do not use, install, modify or
-	redistribute this Apple software.
-	
-	In consideration of your agreement to abide by the following terms,
-	and subject to these terms, Apple grants you a personal, non-exclusive
-	license, under Apple's copyrights in this original Apple software (the
-	"Apple Software"), to use, reproduce, modify and redistribute the
-	Apple Software, with or without modifications, in source and/or binary
-	forms; provided that if you redistribute the Apple Software in its
-	entirety and without modifications, you must retain this notice and
-	the following text and disclaimers in all such redistributions of the
-	Apple Software.  Neither the name, trademarks, service marks or logos
-	of Apple Computer, Inc. may be used to endorse or promote products
-	derived from the Apple Software without specific prior written
-	permission from Apple.  Except as expressly stated in this notice, no
-	other rights or licenses, express or implied, are granted by Apple
-	herein, including but not limited to any patent rights that may be
-	infringed by your derivative works or by other works in which the
-	Apple Software may be incorporated.
-	
-	The Apple Software is provided by Apple on an "AS IS" basis.  APPLE
-	MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION
-	THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND
-	FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE APPLE SOFTWARE OR ITS
-	USE AND OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
-	
-	IN NO EVENT SHALL APPLE BE LIABLE FOR ANY SPECIAL, INDIRECT,
-	INCIDENTAL OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-	PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
-	REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE APPLE SOFTWARE,
-	HOWEVER CAUSED AND WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING
-	NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN IF APPLE HAS BEEN
-	ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+	File Ownership:
+
+		DRI:				Matthias Neeracher    x43683
+
+	Writers:
+
+		(MN)	Matthias Neeracher
+
+	Change History (most recent first):
+
+		$Log: MBCBoardViewTextures.mm,v $
+		Revision 1.12  2004/09/02 11:07:53  neerache
+		Use anisotropic textures
+		
+		Revision 1.11  2004/07/10 04:53:29  neerache
+		Tweak visuals
+		
+		Revision 1.10  2003/11/06 23:30:51  neerache
+		Adjust wording as suggested by Joyce Chow
+		
+		Revision 1.9  2003/10/29 22:39:31  neerache
+		Add tools & clean up copyright references for release
+		
+		Revision 1.8  2003/08/01 23:53:19  neerache
+		Get rid of erroneous use of GL_SRC_COLOR (RADAR 3343477)
+		
+		Revision 1.7  2003/06/05 08:31:26  neerache
+		Added Tuner
+		
+		Revision 1.6  2003/06/04 23:14:05  neerache
+		Neater manipulation widget; remove obsolete graphics options
+		
+		Revision 1.5  2003/06/02 04:21:40  neerache
+		Start implementing drawing styles for board elements
+		
+		Revision 1.4  2003/05/27 03:13:57  neerache
+		Rework game loading/saving code
+		
+		Revision 1.3  2003/05/05 23:52:05  neerache
+		Experimental switch to mipmaps
+		
+		Revision 1.2  2002/10/15 22:49:40  neeri
+		Add support for texture styles
+		
+		Revision 1.1  2002/08/22 23:47:06  neeri
+		Initial Checkin
+		
 */
 
 #import "MBCBoardView.h"
